A few more minor fixes.



git-svn-id: https://llvm.org/svn/llvm-project/llvdb/trunk@105721 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/include/lldb/Core/ValueObjectChild.h b/include/lldb/Core/ValueObjectChild.h
index b5f842c..c632c8e 100644
--- a/include/lldb/Core/ValueObjectChild.h
+++ b/include/lldb/Core/ValueObjectChild.h
@@ -13,7 +13,6 @@
 // C Includes
 // C++ Includes
 // Other libraries and framework includes
-#include "clang/AST/Type.h"
 // Project includes
 #include "lldb/Core/ValueObject.h"
 
diff --git a/include/lldb/Symbol/ClangASTContext.h b/include/lldb/Symbol/ClangASTContext.h
index 56e583c..8c03d37 100644
--- a/include/lldb/Symbol/ClangASTContext.h
+++ b/include/lldb/Symbol/ClangASTContext.h
@@ -14,6 +14,8 @@
 // C++ Includes
 #include <string>
 #include <vector>
+#include <memory>
+#include <stdint.h>
 
 // Other libraries and framework includes
 // Project includes
diff --git a/source/Core/DataBufferMemoryMap.cpp b/source/Core/DataBufferMemoryMap.cpp
index c8ad549..9c63bf1 100644
--- a/source/Core/DataBufferMemoryMap.cpp
+++ b/source/Core/DataBufferMemoryMap.cpp
@@ -97,7 +97,7 @@
 
 //----------------------------------------------------------------------
 // Memory map "length" bytes from "file" starting "offset"
 // bytes into the file. If "length" is set to SIZE_T_MAX, then
 // map as many bytes as possible.
 //
 // Returns the number of bytes mapped starting from the requested
@@ -137,7 +137,7 @@
 // containing valid data from a call to stat().
 //
 // Memory map FILE_LENGTH bytes in FILE starting FILE_OFFSET bytes into
 // the file. If FILE_LENGTH is set to SIZE_T_MAX, then map as many bytes
 // as possible.
 //
 // RETURNS
@@ -154,7 +154,7 @@
         {
             if ((stat.st_mode & S_IFREG) && (stat.st_size > offset))
             {
-                if (length == SIZE_T_MAX)
+                if (length == SIZE_MAX)
                     length = stat.st_size - offset;
 
                 // Cap the length if too much data was requested
@@ -97,7 +97,7 @@
 //----------------------------------------------------------------------
 // Memory map "length" bytes from "file" starting "offset"
-// bytes into the file. If "length" is set to SIZE_T_MAX, then
+// bytes into the file. If "length" is set to SIZE_MAX, then
 // map as many bytes as possible.
 //
@@ -137,7 +137,7 @@
 //
 // Memory map FILE_LENGTH bytes in FILE starting FILE_OFFSET bytes into
-// the file. If FILE_LENGTH is set to SIZE_T_MAX, then map as many bytes
+// the file. If FILE_LENGTH is set to SIZE_MAX, then map as many bytes
 // as possible.
 //